@@ -7,6 +7,8 @@ from __future__ import annotations
 import asyncio
 import json
 import logging
+import os
+import platform
 from dataclasses import dataclass
 from datetime import datetime, timezone
 from pathlib import Path
@@ -163,6 +165,102 @@ class ControlPlaneClient:
     async def close(self) -> None:
         self._stop.set()
 
+    def _get_platform_release(self) -> str:
+        """
+        Get detailed platform release information.
+        
+        Returns:
+            Detailed platform version string based on the operating system.
+        """
+        system = platform.system()
+        
+        if system == "Windows":
+            # Windows: Get version and edition info
+            # platform.platform() returns something like 'Windows-10-10.0.19045-SP0'
+            try:
+                import sys
+                if sys.platform == "win32":
+                    # Try to get Windows version
+                    version = platform.version()  # e.g., '10.0.19045'
+                    release = platform.release()  # e.g., '10' or '11'
+                    
+                    # Try to get edition (Home, Pro, Enterprise, etc.)
+                    try:
+                        import winreg
+                        key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, 
+                                            r"SOFTWARE\Microsoft\Windows NT\CurrentVersion")
+                        edition, _ = winreg.QueryValueEx(key, "EditionID")
+                        display_version, _ = winreg.QueryValueEx(key, "DisplayVersion")
+                        winreg.CloseKey(key)
+                        return f"Windows {release} {edition} ({display_version})"
+                    except:
+                        return f"Windows {release} ({version})"
+            except:
+                pass
+            return platform.platform()
+        
+        elif system == "Linux":
+            # Linux: Try to get distribution info
+            try:
+                # Try using distro package (more reliable)
+                import distro
+                name = distro.name(pretty=True)  # e.g., "Ubuntu 20.04.6 LTS"
+                if name:
+                    return name
+            except ImportError:
+                pass
+            
+            # Fallback: try reading /etc/os-release
+            try:
+                with open("/etc/os-release", "r") as f:
+                    lines = f.readlines()
+                    info = {}
+                    for line in lines:
+                        if "=" in line:
+                            key, value = line.strip().split("=", 1)
+                            info[key] = value.strip('"')
+                    
+                    # Try PRETTY_NAME first, then fallback to NAME + VERSION
+                    if "PRETTY_NAME" in info:
+                        return info["PRETTY_NAME"]
+                    elif "NAME" in info and "VERSION" in info:
+                        return f"{info['NAME']} {info['VERSION']}"
+                    elif "NAME" in info:
+                        return info["NAME"]
+            except:
+                pass
+            
+            # Last resort: return kernel version
+            return f"Linux {platform.release()}"
+        
+        elif system == "Darwin":
+            # macOS: Get version
+            try:
+                mac_ver = platform.mac_ver()[0]
+                if mac_ver:
+                    # Convert version to macOS name if possible
+                    major_version = int(mac_ver.split('.')[0])
+                    if major_version >= 13:
+                        return f"macOS {mac_ver} (Ventura or later)"
+                    elif major_version == 12:
+                        return f"macOS {mac_ver} (Monterey)"
+                    elif major_version == 11:
+                        return f"macOS {mac_ver} (Big Sur)"
+                    elif major_version == 10:
+                        minor = int(mac_ver.split('.')[1])
+                        if minor == 15:
+                            return f"macOS {mac_ver} (Catalina)"
+                        elif minor == 14:
+                            return f"macOS {mac_ver} (Mojave)"
+                    return f"macOS {mac_ver}"
+            except:
+                pass
+            return f"macOS {platform.release()}"
+        
+        else:
+            # Other systems: use platform.platform()
+            return platform.platform()
+
     def _build_headers(self) -> Dict[str, str]:
         """
         Build WebSocket authentication headers.
@@ -189,6 +287,14 @@ class ControlPlaneClient:
             LOG.debug("Including label in WebSocket headers", label=self._config.label)
         else:
             LOG.debug("No label configured, not including x-flowhive-label header")
+        
+        # Add platform information with detailed release info
+        system = platform.system()
+        release = self._get_platform_release()
+        headers["x-flowhive-platform"] = system  # Windows, Linux, Darwin, etc.
+        headers["x-flowhive-platform-release"] = release
+        LOG.debug("Including platform info", platform=system, release=release)
+        
         return headers
 
     async def _session_loop(self, websocket: WebSocketClientProtocol) -> None:
